numpy.polynomial.Hermite
========================

.. currentmodule:: numpy.polynomial

.. autoclass:: Hermite

   

   .. HACK
      .. autosummary::
         :toctree:
      
         Hermite.__init__
         Hermite.convert
         Hermite.copy
         Hermite.cutdeg
         Hermite.degree
         Hermite.deriv
         Hermite.has_samecoef
         Hermite.has_samedomain
         Hermite.has_samewindow
         Hermite.integ
         Hermite.linspace
         Hermite.mapparms
         Hermite.roots
         Hermite.trim
         Hermite.truncate



   

